@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2008-2016 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2008-2024 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -20,7 +20,6 @@ Piece::Piece(const QPoint& pos, int rotation, const QList<Tile*>& tiles, Board*
 	, m_tiles(tiles)
 	, m_shadow(tiles)
 	, m_rotation(0)
-	, m_depth(2)
 	, m_selected(true)
 	, m_changed(false)
 {
@@ -29,15 +28,13 @@ Piece::Piece(const QPoint& pos, int rotation, const QList<Tile*>& tiles, Board*
 
 	// Add bevels to tiles
 	if (m_tiles.first()->bevel().y() == -1) {
-		int count = m_tiles.count();
-		for (int i = 0; i < count; ++i) {
-			Tile* tile = m_tiles.at(i);
+		constexpr int bevels[14] = { 13, 15, 11, 12, 5, 4, 1, 14, 6, 7, 3, 8, 2, 0 };
+		for (Tile* tile : std::as_const(m_tiles)) {
 			int sides = 0;
 			sides |= containsTile(tile->column() - 1, tile->row());
 			sides |= containsTile(tile->column() + 1, tile->row()) << 1;
 			sides |= containsTile(tile->column(), tile->row() - 1) << 2;
 			sides |= containsTile(tile->column(), tile->row() + 1) << 3;
-			static const int bevels[14] = {13, 15, 11, 12, 5, 4, 1, 14, 6, 7, 3, 8, 2, 0};
 			tile->setBevel(bevels[sides - 1]);
 		}
 	}
@@ -52,9 +49,6 @@ Piece::Piece(const QPoint& pos, int rotation, const QList<Tile*>& tiles, Board*
 
 Piece::~Piece()
 {
-	graphics_layer->removeArray(m_tile_array);
-	graphics_layer->removeArray(m_shadow_array);
-
 	qDeleteAll(m_tiles);
 }
 
@@ -62,7 +56,7 @@ Piece::~Piece()
 
 bool Piece::collidesWith(const Piece* other) const
 {
-	if (m_board->marginRect(boundingRect()).intersects(other->boundingRect())) {
+	if (marginRect(boundingRect()).intersects(other->boundingRect())) {
 		return m_collision_region_expanded.intersects(other->m_collision_region);
 	} else {
 		return false;
@@ -73,32 +67,31 @@ bool Piece::collidesWith(const Piece* other) const
 
 QPoint Piece::randomPoint() const
 {
-	Tile* tile = m_tiles.at(m_board->randomInt(m_tiles.count()));
+	const Tile* tile = m_tiles.at(m_board->randomInt(m_tiles.count()));
 	return tile->scenePos() + QPoint(m_board->randomInt(Tile::size), m_board->randomInt(Tile::size));
 }
 
 //-----------------------------------------------------------------------------
 
-void Piece::attachNeighbors()
+void Piece::attachSolutionNeighbors()
 {
-	const auto neighbors = m_neighbors;
-	for (Piece* piece : neighbors) {
+	for (Piece* piece : std::as_const(m_neighbors)) {
 		if (piece->m_rotation != m_rotation) {
 			continue;
 		}
 
-		Tile* tile = m_tiles.first();
-		Tile* piece_tile = piece->m_tiles.first();
-		QPoint grid_delta = piece_tile->gridPos() - tile->gridPos();
+		const Tile* tile = m_tiles.first();
+		const Tile* piece_tile = piece->m_tiles.first();
+		QPoint solution_delta = piece_tile->solutionPos() - tile->solutionPos();
 		for (int i = 0; i < m_rotation; ++i) {
-			QPoint pos = grid_delta;
-			grid_delta.setX( -pos.y() );
-			grid_delta.setY( pos.x() );
+			const QPoint pos = solution_delta;
+			solution_delta.setX(-pos.y());
+			solution_delta.setY(pos.x());
 		}
-		QPoint top_left = tile->scenePos() + grid_delta;
-		QPoint delta = top_left - piece_tile->scenePos();
+		const QPoint top_left = tile->scenePos() + solution_delta;
+		const QPoint delta = top_left - piece_tile->scenePos();
 
-		if (delta.manhattanLength() <= m_board->margin()) {
+		if (delta.manhattanLength() <= m_attach_margin) {
 			piece->moveBy(delta);
 			attach(piece);
 		}
@@ -107,15 +100,15 @@ void Piece::attachNeighbors()
 
 //-----------------------------------------------------------------------------
 
-void Piece::findNeighbors(const QList<Piece*>& pieces)
+void Piece::findSolutionNeighbors(const QList<Piece*>& pieces)
 {
 	// Find neighbor tiles
-	static const QList<QPoint> deltas = QList<QPoint>() << QPoint(-1,0) << QPoint(1,0) << QPoint(0,-1) << QPoint(0,1);
+	constexpr QPoint deltas[4] = { QPoint(-1,0), QPoint(1,0), QPoint(0,-1), QPoint(0,1) };
 	QList<QPoint> tiles;
-	for (Tile* tile : std::as_const(m_shadow)) {
-		QPoint pos(tile->column(), tile->row());
+	for (const Tile* tile : std::as_const(m_shadow)) {
+		const QPoint pos(tile->column(), tile->row());
 		for (const QPoint& delta : deltas) {
-			QPoint neighbor = pos + delta;
+			const QPoint neighbor = pos + delta;
 			if (!containsTile(neighbor.x(), neighbor.y()) && !tiles.contains(neighbor)) {
 				tiles.append(neighbor);
 			}
@@ -135,19 +128,15 @@ void Piece::findNeighbors(const QList<Piece*>& pieces)
 
 //-----------------------------------------------------------------------------
 
-void Piece::pushNeighbors(const QPointF& inertia)
+void Piece::pushCollidingPieces(const QPointF& inertia)
 {
-	while (Piece* neighbor = m_board->findCollidingPiece(this)) {
+	while (Piece* target = m_board->findCollidingPiece(this)) {
 		// Determine which piece to move
-		Piece *source, *target;
-		if (m_tiles.count() >= neighbor->m_tiles.count()) {
-			source = this;
-			target = neighbor;
-		} else {
-			source = neighbor;
-			target = this;
+		Piece* source = this;
+		if (m_tiles.count() < target->m_tiles.count()) {
+			std::swap(source, target);
 		}
-		QRect source_rect = m_board->marginRect(source->boundingRect());
+		const QRect source_rect = marginRect(source->boundingRect());
 
 		// Calculate valid movement vector for target; preserve some motion from last move
 		QPointF vector = target->boundingRect().center() - source_rect.center() + inertia;
@@ -157,16 +146,16 @@ void Piece::pushNeighbors(const QPointF& inertia)
 		}
 
 		// Scale movement vector so that the largest dimension is 1
-		QPointF direction = vector / std::max(fabs(vector.x()), fabs(vector.y()));
+		const QPointF direction = vector / std::max(fabs(vector.x()), fabs(vector.y()));
 
 		// Push target until it is clear from current source
 		// We use a binary-search, pushing away if collision, retracting otherwise
-		QPoint orig = target->m_pos;
-		QRect united = source_rect.united(target->boundingRect());
+		const QPoint orig = target->m_pos;
+		const QRect united = source_rect.united(target->boundingRect());
 		float min = 0.0f;
 		float max = united.width() * united.height();
 		Q_FOREVER {
-			float test = (min + max) / 2.0f;
+			const float test = (min + max) / 2.0f;
 			target->m_pos = orig + (test * direction).toPoint();
 			if (source->collidesWith(target)) {
 				min = test;
@@ -178,12 +167,12 @@ void Piece::pushNeighbors(const QPointF& inertia)
 				Q_ASSERT(max - min > 0.01f);
 			}
 		}
-		target->updateVerts();
+		target->updateFragmentLists();
 		Q_ASSERT(min < max);
 		Q_ASSERT(!source->collidesWith(target));
 
 		// Recurse, and keep inertia for stability.
-		target->pushNeighbors(vector);
+		target->pushCollidingPieces(vector);
 	}
 }
 
@@ -196,7 +185,7 @@ void Piece::rotate(int rotations)
 			rotate();
 		}
 	} else {
-		updateVerts();
+		updateFragmentLists();
 	}
 }
 
@@ -214,9 +203,8 @@ void Piece::rotate(const QPoint& origin)
 	m_rect.setRect(0, 0, m_rect.height(), m_rect.width());
 
 	// Rotate tiles 90 degrees counter-clockwise
-	int count = m_tiles.count();
-	for (int i = 0; i < count; ++i) {
-		m_tiles.at(i)->rotate();
+	for (Tile* tile : std::as_const(m_tiles)) {
+		tile->rotate();
 	}
 
 	// Track how many rotations have occured
@@ -225,15 +213,7 @@ void Piece::rotate(const QPoint& origin)
 		m_rotation = 0;
 	}
 
-	updateVerts();
-}
-
-//-----------------------------------------------------------------------------
-
-void Piece::setDepth(int depth)
-{
-	m_depth = (depth + 1) * 2;
-	updateVerts();
+	updateFragmentLists();
 }
 
 //-----------------------------------------------------------------------------
@@ -255,8 +235,8 @@ void Piece::save(QXmlStreamWriter& xml) const
 	xml.writeAttribute("y", QString::number(m_pos.y()));
 	xml.writeAttribute("rotation", QString::number(m_rotation));
 
-	for (int i = 0; i < m_tiles.count(); ++i) {
-		m_tiles.at(i)->save(xml);
+	for (const Tile* tile : std::as_const(m_tiles)) {
+		tile->save(xml);
 	}
 
 	xml.writeEndElement();
@@ -277,7 +257,7 @@ void Piece::attach(Piece* piece)
 	updateShadow();
 
 	// Update position of attached tiles
-	int rotation = m_rotation;
+	const int rotation = m_rotation;
 	for (int i = rotation; i < 4; ++i) {
 		rotate();
 		piece->rotate();
@@ -302,11 +282,10 @@ void Piece::attach(Piece* piece)
 
 //-----------------------------------------------------------------------------
 
-bool Piece::containsTile(int column, int row)
+bool Piece::containsTile(int column, int row) const
 {
 	bool result = false;
-	for (int i = 0; i < m_tiles.count(); ++i) {
-		const Tile* tile = m_tiles.at(i);
+	for (const Tile* tile : std::as_const(m_tiles)) {
 		if (tile->column() == column && tile->row() == row) {
 			result = true;
 			break;
@@ -323,24 +302,57 @@ void Piece::updateCollisionRegions()
 	m_collision_region = QRegion();
 	m_collision_region_expanded = QRegion();
 	QRect rect(0,0, Tile::size, Tile::size);
-	for (int i = 0; i < m_tiles.count(); ++i) {
-		rect.moveTo(m_tiles.at(i)->scenePos());
+	for (const Tile* tile : std::as_const(m_tiles)) {
+		rect.moveTo(tile->scenePos());
 		m_collision_region += rect;
-		m_collision_region_expanded += m_board->marginRect(rect);
+		m_collision_region_expanded += marginRect(rect);
 	}
 }
 
 //-----------------------------------------------------------------------------
 
+void Piece::updateFragmentLists()
+{
+	m_changed = true;
+	if (!m_selected) {
+		updateCollisionRegions();
+	}
+
+	constexpr QPoint offset(Tile::size / 2, Tile::size / 2);
+
+	// Update tile and bevel fragments
+	m_tiles_list.clear();
+	m_tiles_list.reserve(m_tiles.count());
+	m_bevel_list.clear();
+	m_bevel_list.reserve(m_tiles.count());
+	for (const Tile* tile : std::as_const(m_tiles)) {
+		const QPoint pos = tile->scenePos() + offset;
+		m_tiles_list.append(pos, tile->solutionPos(), Tile::size, rotation() * 90);
+		m_bevel_list.append(pos, tile->bevel() * 512, Tile::size);
+	}
+
+	// Update shadow fragments
+	m_shadow_list.clear();
+	m_shadow_list.reserve(m_shadow.count());
+	for (const Tile* tile : std::as_const(m_shadow)) {
+		m_shadow_list.append(tile->scenePos() + offset, QPointF(0, 0), Tile::size * 2);
+	}
+
+	// Update scene rectangle
+	m_board->updateSceneRectangle(this);
+}
+
+//-----------------------------------------------------------------------------
+
 void Piece::updateShadow()
 {
 	QMutableListIterator<Tile*> i(m_shadow);
 	while (i.hasNext()) {
-		Tile* tile = i.next();
-		if ( containsTile(tile->column() - 1, tile->row())
-			&& containsTile(tile->column() + 1, tile->row())
-			&& containsTile(tile->column(), tile->row() - 1)
-			&& containsTile(tile->column(), tile->row() + 1) ) {
+		const Tile* tile = i.next();
+		if (containsTile(tile->column() - 1, tile->row())
+				&& containsTile(tile->column() + 1, tile->row())
+				&& containsTile(tile->column(), tile->row() - 1)
+				&& containsTile(tile->column(), tile->row() + 1)) {
 			i.remove();
 		}
 	}
@@ -350,14 +362,11 @@ void Piece::updateShadow()
 
 void Piece::updateTiles()
 {
-	int count = m_tiles.count();
-
 	// Find bounding rectangle
-	QPoint top_left = m_tiles.first()->gridPos();
+	QPoint top_left = m_tiles.first()->solutionPos();
 	QPoint bottom_right = top_left + QPoint(Tile::size, Tile::size);
-	QPoint pos;
-	for (int i = 0; i < count; ++i) {
-		pos = m_tiles.at(i)->gridPos();
+	for (const Tile* tile : std::as_const(m_tiles)) {
+		const QPoint pos = tile->solutionPos();
 		top_left.setX( std::min(pos.x(), top_left.x()) );
 		top_left.setY( std::min(pos.y(), top_left.y()) );
 		bottom_right.setX( std::max(pos.x() + Tile::size, bottom_right.x()) );
@@ -366,79 +375,10 @@ void Piece::updateTiles()
 	m_rect.setRect(0, 0, bottom_right.x() - top_left.x(), bottom_right.y() - top_left.y());
 
 	// Shift tiles to be inside rectangle
-	Tile* tile;
-	for (int i = 0; i < count; ++i) {
-		tile = m_tiles.at(i);
+	for (Tile* tile : std::as_const(m_tiles)) {
 		tile->setParent(this);
-		tile->setPos(tile->gridPos() - top_left);
+		tile->setPos(tile->solutionPos() - top_left);
 	}
 }
 
 //-----------------------------------------------------------------------------
-
-void Piece::updateVerts()
-{
-	m_changed = true;
-	if (!m_selected) {
-		updateCollisionRegions();
-	}
-
-	QList<Vertex> verts;
-	int z = m_depth;
-
-	// Update tile verts
-	verts.reserve(m_tiles.count() * 6);
-	for (int i = 0; i < m_tiles.count(); ++i) {
-		Tile* tile = m_tiles.at(i);
-
-		QPoint pos = tile->scenePos();
-		int x1 = pos.x();
-		int y1 = pos.y();
-		int x2 = x1 + Tile::size;
-		int y2 = y1 + Tile::size;
-
-		const QPointF* corners = m_board->corners(rotation());
-		float tx = tile->column() * m_board->tileTextureSize();
-		float ty = tile->row() * m_board->tileTextureSize();
-
-		float bx1 = tile->bevel().x();
-		float by1 = tile->bevel().y();
-		float bx2 = bx1 + 0.125;
-		float by2 = by1 + 0.125;
-
-		verts.append( Vertex::init(x1,y1,z, tx + corners[0].x(),ty + corners[0].y(), bx1,by1) );
-		verts.append( Vertex::init(x1,y2,z, tx + corners[1].x(),ty + corners[1].y(), bx1,by2) );
-		verts.append( Vertex::init(x2,y1,z, tx + corners[3].x(),ty + corners[3].y(), bx2,by1) );
-		verts.append( Vertex::init(x2,y1,z, tx + corners[3].x(),ty + corners[3].y(), bx2,by1) );
-		verts.append( Vertex::init(x1,y2,z, tx + corners[1].x(),ty + corners[1].y(), bx1,by2) );
-		verts.append( Vertex::init(x2,y2,z, tx + corners[2].x(),ty + corners[2].y(), bx2,by2) );
-	}
-	graphics_layer->updateArray(m_tile_array, verts);
-
-	// Update shadow verts
-	z--;
-	static const int offset = Tile::size / 2;
-	static const int size = Tile::size * 2;
-	verts.clear();
-	verts.reserve(m_shadow.count() * 6);
-	for (int i = 0; i < m_shadow.count(); ++i) {
-		QPoint pos = m_shadow.at(i)->scenePos();
-		int x1 = pos.x() - offset;
-		int y1 = pos.y() - offset;
-		int x2 = x1 + size;
-		int y2 = y1 + size;
-
-		verts.append( Vertex::init(x1,y1,z, 0,0) );
-		verts.append( Vertex::init(x1,y2,z, 0,1) );
-		verts.append( Vertex::init(x2,y1,z, 1,0) );
-		verts.append( Vertex::init(x2,y1,z, 1,0) );
-		verts.append( Vertex::init(x1,y2,z, 0,1) );
-		verts.append( Vertex::init(x2,y2,z, 1,1) );
-	}
-	graphics_layer->updateArray(m_shadow_array, verts);
-
-	// Update scene rectangle
-	m_board->updateSceneRectangle(this);
-}
-
-//-----------------------------------------------------------------------------
