@@ -7,6 +7,10 @@
         <source>Open Image</source>
         <translation>Åpne bilde</translation>
     </message>
+    <message>
+        <source>Images</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AppearanceDialog</name>
@@ -120,6 +124,10 @@
         <source>New Game</source>
         <translation>Nytt spill</translation>
     </message>
+    <message>
+        <source>Play Game</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImagePropertiesDialog</name>
@@ -135,6 +143,10 @@
         <source>Tags:</source>
         <translation>Etiketter:</translation>
     </message>
+    <message>
+        <source>New tag name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
@@ -181,22 +193,28 @@
         <source>Cancel</source>
         <translation>Avbryt</translation>
     </message>
-    <message>
-        <source>Remove selected image?</source>
-        <translation>Fjern valgt bilde?</translation>
-    </message>
-    <message>
-        <source>Remove selected image?
-
-There are saved games using this image that will also be removed.</source>
-        <translation>Fjern valgt bilde?
-
-Lagrede spill som bruker dette bildet vil også bli fjernet.</translation>
-    </message>
     <message>
         <source>Untitled</source>
         <translation>Uten tittel</translation>
     </message>
+    <message numerus="yes">
+        <source>Remove %n selected image(s)?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved games using these image(s) will be deleted.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>OpenGameTab</name>
@@ -266,6 +284,10 @@ Lagrede spill som bruker dette bildet vil også bli fjernet.</translation>
         <source>A tag with that name already exists.</source>
         <translation>En etikett med det navnet finnes allerede.</translation>
     </message>
+    <message>
+        <source>Manage Tags...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Window</name>
@@ -437,28 +459,20 @@ Lagrede spill som bruker dette bildet vil også bli fjernet.</translation>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Lisensiert &lt;a href=%1&gt;GPLv3&lt;/a&gt;</translation>
     </message>
+    <message>
+        <source>%p% complete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ZoomSlider</name>
     <message>
-        <source>??%</source>
-        <translation>??%</translation>
-    </message>
-    <message>
-        <source>%1%</source>
-        <translation>%1%</translation>
+        <source>Zoom: %1%</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>main</name>
-    <message>
-        <source>Select OpenGL version.</source>
-        <translation>Velg OpenGL-versjon.</translation>
-    </message>
-    <message>
-        <source>version</source>
-        <translation>versjon</translation>
-    </message>
     <message>
         <source>Images to add to the choose game dialog.</source>
         <translation type="unfinished"></translation>
