@@ -7,6 +7,10 @@
         <source>Open Image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Images</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AppearanceDialog</name>
@@ -118,6 +122,10 @@
         <source>New Game</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Play Game</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImagePropertiesDialog</name>
@@ -133,6 +141,10 @@
         <source>Tags:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>New tag name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
@@ -179,20 +191,26 @@
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
-    <message>
-        <source>Remove selected image?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Remove selected image?
-
-There are saved games using this image that will also be removed.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Untitled</source>
         <translation type="unfinished"></translation>
     </message>
+    <message numerus="yes">
+        <source>Remove %n selected image(s)?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved games using these image(s) will be deleted.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>OpenGameTab</name>
@@ -262,6 +280,10 @@ There are saved games using this image that will also be removed.</source>
         <source>A tag with that name already exists.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Manage Tags...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Window</name>
@@ -433,28 +455,20 @@ There are saved games using this image that will also be removed.</source>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
     </message>
+    <message>
+        <source>%p% complete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ZoomSlider</name>
     <message>
-        <source>??%</source>
-        <translation>??%</translation>
-    </message>
-    <message>
-        <source>%1%</source>
-        <translation>%1%</translation>
+        <source>Zoom: %1%</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>main</name>
-    <message>
-        <source>Select OpenGL version.</source>
-        <translation>选择 OpenGL 版本。</translation>
-    </message>
-    <message>
-        <source>version</source>
-        <translation>版本</translation>
-    </message>
     <message>
         <source>Images to add to the choose game dialog.</source>
         <translation type="unfinished"></translation>
